@@ -1,46 +1,29 @@
 /*
-   This file is part of the KDE games kwin4 program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games kwin4 program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// Header includes
 #include "kwin4view.h"
 
-// Standard includes
-#include <cmath>
-
-// Qt includes
-#include <QColor>
-#include <QEvent>
-#include <QElapsedTimer>
-
-// KDE includes
-#include "kfourinline_debug.h"
-
-#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
-#include <libkdegamesprivate/kgame/kplayer.h>
-
-// Local includes
+// own
 #include "displayintro.h"
 #include "displaygame.h"
 #include "spritenotify.h"
 #include "score.h"
 #include "reflectiongraphicsscene.h"
+#include "kfourinline_debug.h"
+// KDEGames
+#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
+#include <libkdegamesprivate/kgame/kplayer.h>
+// Qt
+#include <QColor>
+#include <QEvent>
+#include <QElapsedTimer>
+// Std
+#include <cmath>
+
 
 // How many time measurements for average
 #define MEASUREMENT_LIST_SIZE  50
